aboutsummaryrefslogtreecommitdiffhomepage
path: root/unsupported/Eigen/src/Skyline
diff options
context:
space:
mode:
authorGravatar Hauke Heibel <hauke.heibel@gmail.com>2010-10-26 16:47:01 +0200
committerGravatar Hauke Heibel <hauke.heibel@gmail.com>2010-10-26 16:47:01 +0200
commitc738cd56ebdafe986c7edeb2621ec25f3c0b29d9 (patch)
tree2ff118b343b69a7dd68d7ad7d898fdfdc82c58ce /unsupported/Eigen/src/Skyline
parent2fbb9932b0f517643c5f05e4056b939b73956b00 (diff)
Renamed cleantype to remove_all since it is close to remove_{const|pointer|reference}.
Diffstat (limited to 'unsupported/Eigen/src/Skyline')
-rw-r--r--unsupported/Eigen/src/Skyline/SkylineProduct.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/unsupported/Eigen/src/Skyline/SkylineProduct.h b/unsupported/Eigen/src/Skyline/SkylineProduct.h
index d7c536880..aeedc47ec 100644
--- a/unsupported/Eigen/src/Skyline/SkylineProduct.h
+++ b/unsupported/Eigen/src/Skyline/SkylineProduct.h
@@ -36,8 +36,8 @@ struct SkylineProductReturnType {
template<typename LhsNested, typename RhsNested, int ProductMode>
struct internal::traits<SkylineProduct<LhsNested, RhsNested, ProductMode> > {
// clean the nested types:
- typedef typename internal::cleantype<LhsNested>::type _LhsNested;
- typedef typename internal::cleantype<RhsNested>::type _RhsNested;
+ typedef typename internal::remove_all<LhsNested>::type _LhsNested;
+ typedef typename internal::remove_all<RhsNested>::type _RhsNested;
typedef typename _LhsNested::Scalar Scalar;
enum {
@@ -133,8 +133,8 @@ protected:
template<typename Lhs, typename Rhs, typename Dest>
EIGEN_DONT_INLINE void skyline_row_major_time_dense_product(const Lhs& lhs, const Rhs& rhs, Dest& dst) {
- typedef typename cleantype<Lhs>::type _Lhs;
- typedef typename cleantype<Rhs>::type _Rhs;
+ typedef typename remove_all<Lhs>::type _Lhs;
+ typedef typename remove_all<Rhs>::type _Rhs;
typedef typename traits<Lhs>::Scalar Scalar;
enum {
@@ -196,8 +196,8 @@ EIGEN_DONT_INLINE void skyline_row_major_time_dense_product(const Lhs& lhs, cons
template<typename Lhs, typename Rhs, typename Dest>
EIGEN_DONT_INLINE void skyline_col_major_time_dense_product(const Lhs& lhs, const Rhs& rhs, Dest& dst) {
- typedef typename cleantype<Lhs>::type _Lhs;
- typedef typename cleantype<Rhs>::type _Rhs;
+ typedef typename remove_all<Lhs>::type _Lhs;
+ typedef typename remove_all<Rhs>::type _Rhs;
typedef typename traits<Lhs>::Scalar Scalar;
enum {
@@ -264,7 +264,7 @@ template<typename Lhs, typename Rhs, typename ResultType,
template<typename Lhs, typename Rhs, typename ResultType>
struct skyline_product_selector<Lhs, Rhs, ResultType, RowMajor> {
- typedef typename traits<typename cleantype<Lhs>::type>::Scalar Scalar;
+ typedef typename traits<typename remove_all<Lhs>::type>::Scalar Scalar;
static void run(const Lhs& lhs, const Rhs& rhs, ResultType & res) {
skyline_row_major_time_dense_product<Lhs, Rhs, ResultType > (lhs, rhs, res);
@@ -273,7 +273,7 @@ struct skyline_product_selector<Lhs, Rhs, ResultType, RowMajor> {
template<typename Lhs, typename Rhs, typename ResultType>
struct skyline_product_selector<Lhs, Rhs, ResultType, ColMajor> {
- typedef typename traits<typename cleantype<Lhs>::type>::Scalar Scalar;
+ typedef typename traits<typename remove_all<Lhs>::type>::Scalar Scalar;
static void run(const Lhs& lhs, const Rhs& rhs, ResultType & res) {
skyline_col_major_time_dense_product<Lhs, Rhs, ResultType > (lhs, rhs, res);
@@ -285,9 +285,9 @@ struct skyline_product_selector<Lhs, Rhs, ResultType, ColMajor> {
// template<typename Derived>
// template<typename Lhs, typename Rhs >
// Derived & MatrixBase<Derived>::lazyAssign(const SkylineProduct<Lhs, Rhs, SkylineTimeDenseProduct>& product) {
// typedef typename internal::cleantype<Lhs>::type _Lhs;
// internal::skyline_product_selector<typename internal::cleantype<Lhs>::type,
// typename internal::cleantype<Rhs>::type,
// Derived>::run(product.lhs(), product.rhs(), derived());
//
// return derived();
@@ -285,9 +285,9 @@ struct skyline_product_selector<Lhs, Rhs, ResultType, ColMajor> {
// template<typename Lhs, typename Rhs >
// Derived & MatrixBase<Derived>::lazyAssign(const SkylineProduct<Lhs, Rhs, SkylineTimeDenseProduct>& product) {
-// typedef typename internal::cleantype<Lhs>::type _Lhs;
-// internal::skyline_product_selector<typename internal::cleantype<Lhs>::type,
-// typename internal::cleantype<Rhs>::type,
+// typedef typename internal::remove_all<Lhs>::type _Lhs;
+// internal::skyline_product_selector<typename internal::remove_all<Lhs>::type,
+// typename internal::remove_all<Rhs>::type,
// Derived>::run(product.lhs(), product.rhs(), derived());
//